@@ -8,9 +8,10 @@ import zipfile
 from pathlib import Path
 from threading import Lock
 
-from argostranslate import networking
-from argostranslate import settings
-from argostranslate.utils import info, error
+import packaging.version
+
+from argostranslate import networking, settings
+from argostranslate.utils import error, info
 
 """
 ## `package` module example usage
@@ -194,6 +195,20 @@ class Package(IPackage):
             metadata = json.load(metadata_file)
             self.load_metadata_from_json(metadata)
 
+    def update(self):
+        """Update the package if a newer version is available."""
+        for available_package in get_available_packages():
+            if (
+                available_package.from_code == self.from_code
+                and available_package.to_code == self.to_code
+            ):
+                if packaging.version.parse(
+                    available_package.package_version
+                ) > packaging.version.parse(self.package_version):
+                    new_package_path = available_package.download()
+                    uninstall(self)
+                    install_from_path(new_package_path)
+
     def get_readme(self) -> str | None:
         """Returns the text of the README.md in this package.
 
@@ -263,6 +278,7 @@ class AvailablePackage(IPackage):
     def install(self):
         download_path = self.download()
         install_from_path(download_path)
+        download_path.unlink()
 
     def get_description(self):
         return "{} → {}".format(self.from_name, self.to_name)
@@ -315,7 +331,7 @@ def update_package_index():
             f.write(data)
 
 
-def get_available_packages() -> list[Package]:
+def get_available_packages() -> list[AvailablePackage]:
     """Returns a list of AvailablePackages from the package index."""
 
     try:
@@ -344,9 +360,8 @@ def get_available_packages() -> list[Package]:
 
             return packages
     except FileNotFoundError:
-        raise Exception(
-            "Local package index not found, use package.update_package_index() to load it"
-        )
+        update_package_index()
+        return get_available_packages()
 
 
 def argospm_package_name(pkg: IPackage) -> str:
