@@ -1,11 +1,13 @@
 from __future__ import annotations
 
+from typing import List
+
 import ctranslate2
 import sentencepiece as spm
 import stanza
 from ctranslate2 import Translator
 
-from argostranslate import package, settings, sbd, apis, fewshot
+from argostranslate import apis, fewshot, package, sbd, settings
 from argostranslate.models import ILanguageModel
 from argostranslate.package import Package
 from argostranslate.utils import info
@@ -246,7 +248,7 @@ class CompositeTranslation(ITranslation):
                         t2_hypothesis.value, t1_hypothesis.score + t2_hypothesis.score
                     )
                 )
-        to_return.sort()
+        to_return.sort(reverse=True)
         return to_return[0:num_hypotheses]
 
 
@@ -488,6 +490,19 @@ def apply_packaged_translation(
     return value_hypotheses
 
 
+class InstalledTranslate:
+    """
+    Global storage of instances of the CachedTranslation class by unique keys.
+    To avoid creating unnecessary objects in memory.
+    """
+
+    package_key: str
+    cached_translation: CachedTranslation
+
+
+installed_translates: List[InstalledTranslate] = []
+
+
 def get_installed_languages() -> list[Language]:
     """Returns a list of Languages installed from packages"""
 
@@ -518,9 +533,23 @@ def get_installed_languages() -> list[Language]:
                 language_of_code[pkg.to_code] = Language(pkg.to_code, pkg.to_name)
             from_lang = language_of_code[pkg.from_code]
             to_lang = language_of_code[pkg.to_code]
-            translation_to_add = CachedTranslation(
-                PackageTranslation(from_lang, to_lang, pkg)
+
+            package_key = f"{pkg.from_code}-{pkg.to_code}"
+            contain = list(
+                filter(lambda x: x.package_key == package_key, installed_translates)
             )
+            translation_to_add: CachedTranslation
+            if len(contain) == 0:
+                translation_to_add = CachedTranslation(
+                    PackageTranslation(from_lang, to_lang, pkg)
+                )
+                saved_cache = InstalledTranslate()
+                saved_cache.package_key = package_key
+                saved_cache.cached_translation = translation_to_add
+                installed_translates.append(saved_cache)
+            else:
+                translation_to_add = contain[0].cached_translation
+
             from_lang.translations_from.append(translation_to_add)
             to_lang.translations_to.append(translation_to_add)
 
